@@ -22,7 +22,6 @@ from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.i18n import _
-from openstackclient.i18n import _LE
 
 
 LOG = logging.getLogger(__name__)
@@ -50,8 +49,7 @@ class DeleteService(command.Command):
             except Exception as e:
                 result += 1
                 LOG.error(_("Failed to delete compute service with "
-                          "ID '%(service)s': %(e)s")
-                          % {'service': s, 'e': e})
+                          "ID '%(service)s': %(e)s"), {'service': s, 'e': e})
 
         if result > 0:
             total = len(parsed_args.service)
@@ -190,7 +188,7 @@ class SetService(command.Command):
                         cs.disable(parsed_args.host, parsed_args.service)
         except Exception:
             status = "enabled" if enabled else "disabled"
-            LOG.error(_LE("Failed to set service status to %s"), status)
+            LOG.error("Failed to set service status to %s", status)
             result += 1
 
         force_down = None
@@ -204,7 +202,7 @@ class SetService(command.Command):
                               force_down=force_down)
         except Exception:
             state = "down" if force_down else "up"
-            LOG.error(_LE("Failed to set service state to %s"), state)
+            LOG.error("Failed to set service state to %s", state)
             result += 1
 
         if result > 0:
