@@ -42,7 +42,7 @@ _formatters = {
 }
 
 
-def _get_network_columns(item):
+def _get_columns_network(item):
     column_map = {
         'subnet_ids': 'subnets',
         'is_admin_state_up': 'admin_state_up',
@@ -59,16 +59,14 @@ def _get_network_columns(item):
     return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
-def _get_columns(item):
-    columns = list(item.keys())
-    if 'tenant_id' in columns:
-        columns.remove('tenant_id')
-    if 'project_id' not in columns:
-        columns.append('project_id')
-    return tuple(sorted(columns))
+def _get_columns_compute(item):
+    column_map = {
+        'tenant_id': 'project_id',
+    }
+    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
-def _get_attrs(client_manager, parsed_args):
+def _get_attrs_network(client_manager, parsed_args):
     attrs = {}
     if parsed_args.name is not None:
         attrs['name'] = str(parsed_args.name)
@@ -93,7 +91,9 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.project,
             parsed_args.project_domain,
         ).id
+        # TODO(dtroyer): Remove tenant_id when we clean up the SDK refactor
         attrs['tenant_id'] = project_id
+        attrs['project_id'] = project_id
 
     # "network set" command doesn't support setting availability zone hints.
     if 'availability_zone_hints' in parsed_args and \
@@ -109,10 +109,10 @@ def _get_attrs(client_manager, parsed_args):
         attrs['router:external'] = False
     if parsed_args.external:
         attrs['router:external'] = True
-        if parsed_args.no_default:
-            attrs['is_default'] = False
-        if parsed_args.default:
-            attrs['is_default'] = True
+    if parsed_args.no_default:
+        attrs['is_default'] = False
+    if parsed_args.default:
+        attrs['is_default'] = True
     # Update Provider network options
     if parsed_args.provider_network_type:
         attrs['provider:network_type'] = parsed_args.provider_network_type
@@ -135,16 +135,27 @@ def _get_attrs(client_manager, parsed_args):
     return attrs
 
 
+def _get_attrs_compute(client_manager, parsed_args):
+    attrs = {}
+    if parsed_args.name is not None:
+        attrs['name'] = str(parsed_args.name)
+    if parsed_args.share:
+        attrs['share_subnet'] = True
+    if parsed_args.no_share:
+        attrs['share_subnet'] = False
+    if parsed_args.subnet is not None:
+        attrs['subnet'] = parsed_args.subnet
+    return attrs
+
+
 def _add_additional_network_options(parser):
     # Add additional network options
 
     parser.add_argument(
         '--provider-network-type',
         metavar='<provider-network-type>',
-        choices=['flat', 'geneve', 'gre', 'local',
-                 'vlan', 'vxlan'],
         help=_("The physical mechanism by which the virtual network "
-               "is implemented. The supported options are: "
+               "is implemented. For example: "
                "flat, geneve, gre, local, vlan, vxlan."))
     parser.add_argument(
         '--provider-physical-network',
@@ -170,19 +181,6 @@ def _add_additional_network_options(parser):
         help=_("Do not make the network VLAN transparent"))
 
 
-def _get_attrs_compute(client_manager, parsed_args):
-    attrs = {}
-    if parsed_args.name is not None:
-        attrs['label'] = str(parsed_args.name)
-    if parsed_args.share:
-        attrs['share_address'] = True
-    if parsed_args.no_share:
-        attrs['share_address'] = False
-    if parsed_args.subnet is not None:
-        attrs['cidr'] = parsed_args.subnet
-    return attrs
-
-
 # TODO(sindhu): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
 class CreateNetwork(common.NetworkAndComputeShowOne):
@@ -291,23 +289,24 @@ class CreateNetwork(common.NetworkAndComputeShowOne):
         parser.add_argument(
             '--subnet',
             metavar='<subnet>',
+            required=True,
             help=_("IPv4 subnet for fixed IPs (in CIDR notation)")
         )
         return parser
 
     def take_action_network(self, client, parsed_args):
-        attrs = _get_attrs(self.app.client_manager, parsed_args)
+        attrs = _get_attrs_network(self.app.client_manager, parsed_args)
         obj = client.create_network(**attrs)
-        display_columns, columns = _get_network_columns(obj)
+        display_columns, columns = _get_columns_network(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
         attrs = _get_attrs_compute(self.app.client_manager, parsed_args)
-        obj = client.networks.create(**attrs)
-        columns = _get_columns(obj._info)
-        data = utils.get_dict_properties(obj._info, columns)
-        return (columns, data)
+        obj = client.api.network_create(**attrs)
+        display_columns, columns = _get_columns_compute(obj)
+        data = utils.get_dict_properties(obj, columns)
+        return (display_columns, data)
 
 
 class DeleteNetwork(common.NetworkAndComputeDelete):
@@ -332,8 +331,7 @@ class DeleteNetwork(common.NetworkAndComputeDelete):
         client.delete_network(obj)
 
     def take_action_compute(self, client, parsed_args):
-        network = utils.find_resource(client.networks, self.r)
-        client.networks.delete(network.id)
+        client.api.network_delete(self.r)
 
 
 # TODO(sindhu): Use the SDK resource mapped attribute names once the
@@ -420,7 +418,11 @@ class ListNetwork(common.NetworkAndComputeLister):
             help=_("List networks according to VLAN ID for VLAN networks "
                    "or Tunnel ID for GENEVE/GRE/VXLAN networks")
         )
-
+        parser.add_argument(
+            '--agent',
+            metavar='<agent-id>',
+            dest='agent_id',
+            help=_('List networks hosted by agent (ID only)'))
         return parser
 
     def take_action_network(self, client, parsed_args):
@@ -450,6 +452,26 @@ class ListNetwork(common.NetworkAndComputeLister):
                 'Router Type',
                 'Availability Zones',
             )
+        elif parsed_args.agent_id:
+            columns = (
+                'id',
+                'name',
+                'subnet_ids'
+            )
+            column_headers = (
+                'ID',
+                'Name',
+                'Subnets',
+            )
+            client = self.app.client_manager.network
+            dhcp_agent = client.get_agent(parsed_args.agent_id)
+            data = client.dhcp_agent_hosting_networks(dhcp_agent)
+
+            return (column_headers,
+                    (utils.get_item_properties(
+                        s, columns,
+                        formatters=_formatters,
+                    ) for s in data))
         else:
             columns = (
                 'id',
@@ -530,10 +552,10 @@ class ListNetwork(common.NetworkAndComputeLister):
             'Subnet',
         )
 
-        data = client.networks.list()
+        data = client.api.network_list()
 
         return (column_headers,
-                (utils.get_item_properties(
+                (utils.get_dict_properties(
                     s, columns,
                     formatters=_formatters,
                 ) for s in data))
@@ -639,7 +661,7 @@ class SetNetwork(command.Command):
         client = self.app.client_manager.network
         obj = client.find_network(parsed_args.network, ignore_missing=False)
 
-        attrs = _get_attrs(self.app.client_manager, parsed_args)
+        attrs = _get_attrs_network(self.app.client_manager, parsed_args)
         client.update_network(obj, **attrs)
 
 
@@ -656,15 +678,12 @@ class ShowNetwork(common.NetworkAndComputeShowOne):
 
     def take_action_network(self, client, parsed_args):
         obj = client.find_network(parsed_args.network, ignore_missing=False)
-        display_columns, columns = _get_network_columns(obj)
+        display_columns, columns = _get_columns_network(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
-        obj = utils.find_resource(
-            client.networks,
-            parsed_args.network,
-        )
-        columns = _get_columns(obj._info)
-        data = utils.get_dict_properties(obj._info, columns)
-        return (columns, data)
+        obj = client.api.network_find(parsed_args.network)
+        display_columns, columns = _get_columns_compute(obj)
+        data = utils.get_dict_properties(obj, columns)
+        return (display_columns, data)
