@@ -17,6 +17,7 @@ import copy
 import mock
 import uuid
 
+from openstackclient.api import compute_v2
 from openstackclient.tests.unit import fakes
 from openstackclient.tests.unit.identity.v2_0 import fakes as identity_fakes
 from openstackclient.tests.unit.image.v2 import fakes as image_fakes
@@ -180,21 +181,6 @@ class FakeComputev2Client(object):
         self.hypervisors_stats = mock.Mock()
         self.hypervisors_stats.resource_class = fakes.FakeResource(None, {})
 
-        self.security_groups = mock.Mock()
-        self.security_groups.resource_class = fakes.FakeResource(None, {})
-
-        self.security_group_rules = mock.Mock()
-        self.security_group_rules.resource_class = fakes.FakeResource(None, {})
-
-        self.floating_ips = mock.Mock()
-        self.floating_ips.resource_class = fakes.FakeResource(None, {})
-
-        self.floating_ip_pools = mock.Mock()
-        self.floating_ip_pools.resource_class = fakes.FakeResource(None, {})
-
-        self.networks = mock.Mock()
-        self.networks.resource_class = fakes.FakeResource(None, {})
-
         self.keypairs = mock.Mock()
         self.keypairs.resource_class = fakes.FakeResource(None, {})
 
@@ -204,6 +190,9 @@ class FakeComputev2Client(object):
         self.server_groups = mock.Mock()
         self.server_groups.resource_class = fakes.FakeResource(None, {})
 
+        self.instance_action = mock.Mock()
+        self.instance_action.resource_class = fakes.FakeResource(None, {})
+
         self.auth_token = kwargs['token']
 
         self.management_url = kwargs['endpoint']
@@ -219,6 +208,11 @@ class TestComputev2(utils.TestCommand):
             token=fakes.AUTH_TOKEN,
         )
 
+        self.app.client_manager.compute.api = compute_v2.APIv2(
+            session=self.app.client_manager.session,
+            endpoint=fakes.AUTH_URL,
+        )
+
         self.app.client_manager.identity = identity_fakes.FakeIdentityv2Client(
             endpoint=fakes.AUTH_URL,
             token=fakes.AUTH_TOKEN,
@@ -482,11 +476,7 @@ class FakeSecurityGroup(object):
 
         # Overwrite default attributes.
         security_group_attrs.update(attrs)
-
-        security_group = fakes.FakeResource(
-            info=copy.deepcopy(security_group_attrs),
-            loaded=True)
-        return security_group
+        return security_group_attrs
 
     @staticmethod
     def create_security_groups(attrs=None, count=2):
@@ -554,10 +544,7 @@ class FakeSecurityGroupRule(object):
         # Overwrite default attributes.
         security_group_rule_attrs.update(attrs)
 
-        security_group_rule = fakes.FakeResource(
-            info=copy.deepcopy(security_group_rule_attrs),
-            loaded=True)
-        return security_group_rule
+        return security_group_rule_attrs
 
     @staticmethod
     def create_security_group_rules(attrs=None, count=2):
@@ -656,6 +643,47 @@ class FakeServer(object):
         return mock.Mock(side_effect=servers)
 
 
+class FakeServerEvent(object):
+    """Fake one or more server event."""
+
+    @staticmethod
+    def create_one_server_event(attrs=None):
+        """Create a fake server event.
+
+        :param attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with id and other attributes
+        """
+        attrs = attrs or {}
+
+        # Set default attributes
+        server_event_info = {
+            "instance_uuid": "server-event-" + uuid.uuid4().hex,
+            "user_id": "user-id-" + uuid.uuid4().hex,
+            "start_time": "2017-02-27T07:47:13.000000",
+            "request_id": "req-" + uuid.uuid4().hex,
+            "action": "create",
+            "message": None,
+            "project_id": "project-id-" + uuid.uuid4().hex,
+            "events": [{
+                "finish_time": "2017-02-27T07:47:25.000000",
+                "start_time": "2017-02-27T07:47:15.000000",
+                "traceback": None,
+                "event": "compute__do_build_and_run_instance",
+                "result": "Success"
+            }]
+        }
+        # Overwrite default attributes
+        server_event_info.update(attrs)
+
+        server_event = fakes.FakeResource(
+            info=copy.deepcopy(server_event_info),
+            loaded=True,
+        )
+        return server_event
+
+
 class FakeService(object):
     """Fake one or more services."""
 
@@ -976,11 +1004,7 @@ class FakeFloatingIP(object):
         # Overwrite default attributes.
         floating_ip_attrs.update(attrs)
 
-        floating_ip = fakes.FakeResource(
-            info=copy.deepcopy(floating_ip_attrs),
-            loaded=True)
-
-        return floating_ip
+        return floating_ip_attrs
 
     @staticmethod
     def create_floating_ips(attrs=None, count=2):
@@ -1041,11 +1065,7 @@ class FakeFloatingIPPool(object):
         # Overwrite default attributes.
         floating_ip_pool_attrs.update(attrs)
 
-        floating_ip_pool = fakes.FakeResource(
-            info=copy.deepcopy(floating_ip_pool_attrs),
-            loaded=True)
-
-        return floating_ip_pool
+        return floating_ip_pool_attrs
 
     @staticmethod
     def create_floating_ip_pools(attrs=None, count=2):
@@ -1119,10 +1139,7 @@ class FakeNetwork(object):
         # Overwrite default attributes.
         network_attrs.update(attrs)
 
-        network = fakes.FakeResource(info=copy.deepcopy(network_attrs),
-                                     loaded=True)
-
-        return network
+        return network_attrs
 
     @staticmethod
     def create_networks(attrs=None, count=2):
@@ -1313,3 +1330,67 @@ class FakeUsage(object):
             usages.append(FakeUsage.create_one_usage(attrs))
 
         return usages
+
+
+class FakeQuota(object):
+    """Fake quota"""
+
+    @staticmethod
+    def create_one_comp_quota(attrs=None):
+        """Create one quota"""
+
+        attrs = attrs or {}
+
+        quota_attrs = {
+            'id': 'project-id-' + uuid.uuid4().hex,
+            'cores': 20,
+            'fixed_ips': 30,
+            'injected_files': 100,
+            'injected_file_content_bytes': 10240,
+            'injected_file_path_bytes': 255,
+            'instances': 50,
+            'key_pairs': 20,
+            'metadata_items': 10,
+            'ram': 51200,
+            'server_groups': 10,
+            'server_group_members': 10
+        }
+
+        quota_attrs.update(attrs)
+        quota = fakes.FakeResource(
+            info=copy.deepcopy(quota_attrs),
+            loaded=True)
+
+        quota.project_id = quota_attrs['id']
+
+        return quota
+
+    @staticmethod
+    def create_one_default_comp_quota(attrs=None):
+        """Crate one quota"""
+
+        attrs = attrs or {}
+
+        quota_attrs = {
+            'id': 'project-id-' + uuid.uuid4().hex,
+            'cores': 10,
+            'fixed_ips': 10,
+            'injected_files': 100,
+            'injected_file_content_bytes': 10240,
+            'injected_file_path_bytes': 255,
+            'instances': 20,
+            'key_pairs': 20,
+            'metadata_items': 10,
+            'ram': 51200,
+            'server_groups': 10,
+            'server_group_members': 10
+        }
+
+        quota_attrs.update(attrs)
+        quota = fakes.FakeResource(
+            info=copy.deepcopy(quota_attrs),
+            loaded=True)
+
+        quota.project_id = quota_attrs['id']
+
+        return quota
