@@ -57,7 +57,8 @@ class TestPort(network_fakes.TestNetworkV2):
             'network_id',
             'port_security_enabled',
             'project_id',
-            'security_groups',
+            'qos_policy_id',
+            'security_group_ids',
             'status',
         )
 
@@ -82,7 +83,8 @@ class TestPort(network_fakes.TestNetworkV2):
             fake_port.network_id,
             fake_port.port_security_enabled,
             fake_port.project_id,
-            utils.format_list(fake_port.security_groups),
+            fake_port.qos_policy_id,
+            utils.format_list(fake_port.security_group_ids),
             fake_port.status,
         )
 
@@ -251,7 +253,7 @@ class TestCreatePort(TestPort):
         verifylist = [
             ('network', self._port.network_id,),
             ('enable', True),
-            ('security_groups', [secgroup.id]),
+            ('security_group', [secgroup.id]),
             ('name', 'test-port'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -261,7 +263,7 @@ class TestCreatePort(TestPort):
         self.network.create_port.assert_called_once_with(**{
             'admin_state_up': True,
             'network_id': self._port.network_id,
-            'security_groups': [secgroup.id],
+            'security_group_ids': [secgroup.id],
             'name': 'test-port',
         })
 
@@ -309,7 +311,7 @@ class TestCreatePort(TestPort):
         verifylist = [
             ('network', self._port.network_id,),
             ('enable', True),
-            ('security_groups', [sg_1.id, sg_2.id]),
+            ('security_group', [sg_1.id, sg_2.id]),
             ('name', 'test-port'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -319,7 +321,7 @@ class TestCreatePort(TestPort):
         self.network.create_port.assert_called_once_with(**{
             'admin_state_up': True,
             'network_id': self._port.network_id,
-            'security_groups': [sg_1.id, sg_2.id],
+            'security_group_ids': [sg_1.id, sg_2.id],
             'name': 'test-port',
         })
 
@@ -346,7 +348,7 @@ class TestCreatePort(TestPort):
         self.network.create_port.assert_called_once_with(**{
             'admin_state_up': True,
             'network_id': self._port.network_id,
-            'security_groups': [],
+            'security_group_ids': [],
             'name': 'test-port',
         })
 
@@ -422,6 +424,35 @@ class TestCreatePort(TestPort):
         self.assertEqual(ref_columns, columns)
         self.assertEqual(ref_data, data)
 
+    def test_create_port_with_qos(self):
+        qos_policy = network_fakes.FakeNetworkQosPolicy.create_one_qos_policy()
+        self.network.find_qos_policy = mock.Mock(return_value=qos_policy)
+        arglist = [
+            '--network', self._port.network_id,
+            '--qos-policy', qos_policy.id,
+            'test-port',
+        ]
+        verifylist = [
+            ('network', self._port.network_id,),
+            ('enable', True),
+            ('qos_policy', qos_policy.id),
+            ('name', 'test-port'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        self.network.create_port.assert_called_once_with(**{
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'qos_policy_id': qos_policy.id,
+            'name': 'test-port',
+        })
+
+        ref_columns, ref_data = self._get_common_cols_data(self._port)
+        self.assertEqual(ref_columns, columns)
+        self.assertEqual(ref_data, data)
+
     def test_create_port_security_enabled(self):
         arglist = [
             '--network', self._port.network_id,
@@ -590,7 +621,7 @@ class TestListPort(TestPort):
             prt.mac_address,
             utils.format_list_of_dicts(prt.fixed_ips),
             prt.status,
-            utils.format_list(prt.security_groups),
+            utils.format_list(prt.security_group_ids),
             prt.device_owner,
         ))
 
@@ -727,6 +758,92 @@ class TestListPort(TestPort):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
+    def test_port_list_fixed_ip_opt_ip_address(self):
+        ip_address = self._ports[0].fixed_ips[0]['ip_address']
+        arglist = [
+            '--fixed-ip', "ip-address=%s" % ip_address,
+        ]
+        verifylist = [
+            ('fixed_ip', [{'ip-address': ip_address}])
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ports.assert_called_once_with(**{
+            'fixed_ips': ['ip_address=%s' % ip_address]})
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
+    def test_port_list_fixed_ip_opt_subnet_id(self):
+        subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
+        arglist = [
+            '--fixed-ip', "subnet=%s" % subnet_id,
+        ]
+        verifylist = [
+            ('fixed_ip', [{'subnet': subnet_id}])
+        ]
+
+        self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'id': subnet_id})
+        self.network.find_subnet = mock.Mock(return_value=self.fake_subnet)
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ports.assert_called_once_with(**{
+            'fixed_ips': ['subnet_id=%s' % subnet_id]})
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
+    def test_port_list_fixed_ip_opts(self):
+        subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
+        ip_address = self._ports[0].fixed_ips[0]['ip_address']
+        arglist = [
+            '--fixed-ip', "subnet=%s,ip-address=%s" % (subnet_id,
+                                                       ip_address)
+        ]
+        verifylist = [
+            ('fixed_ip', [{'subnet': subnet_id,
+                          'ip-address': ip_address}])
+        ]
+
+        self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'id': subnet_id})
+        self.network.find_subnet = mock.Mock(return_value=self.fake_subnet)
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ports.assert_called_once_with(**{
+            'fixed_ips': ['subnet_id=%s' % subnet_id,
+                          'ip_address=%s' % ip_address]})
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
+    def test_port_list_fixed_ips(self):
+        subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
+        ip_address = self._ports[0].fixed_ips[0]['ip_address']
+        arglist = [
+            '--fixed-ip', "subnet=%s" % subnet_id,
+            '--fixed-ip', "ip-address=%s" % ip_address,
+        ]
+        verifylist = [
+            ('fixed_ip', [{'subnet': subnet_id},
+                          {'ip-address': ip_address}])
+        ]
+
+        self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'id': subnet_id})
+        self.network.find_subnet = mock.Mock(return_value=self.fake_subnet)
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ports.assert_called_once_with(**{
+            'fixed_ips': ['subnet_id=%s' % subnet_id,
+                          'ip_address=%s' % ip_address]})
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
     def test_list_port_with_long(self):
         arglist = [
             '--long',
@@ -797,26 +914,69 @@ class TestSetPort(TestPort):
         # Get the command object to test
         self.cmd = port.SetPort(self.app, self.namespace)
 
-    def test_set_fixed_ip(self):
+    def test_set_port_defaults(self):
         arglist = [
-            '--fixed-ip', 'ip-address=10.0.0.11',
             self._port.name,
         ]
         verifylist = [
-            ('fixed_ip', [{'ip-address': '10.0.0.11'}]),
             ('port', self._port.name),
         ]
-
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        result = self.cmd.take_action(parsed_args)
 
-        attrs = {
-            'fixed_ips': [{'ip_address': '10.0.0.11'}],
-        }
+        result = self.cmd.take_action(parsed_args)
+        attrs = {}
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_set_dns_name(self):
+    def test_set_port_fixed_ip(self):
+        _testport = network_fakes.FakePort.create_one_port(
+            {'fixed_ips': [{'ip_address': '0.0.0.1'}]})
+        self.network.find_port = mock.Mock(return_value=_testport)
+        arglist = [
+            '--fixed-ip', 'ip-address=10.0.0.12',
+            _testport.name,
+        ]
+        verifylist = [
+            ('fixed_ip', [{'ip-address': '10.0.0.12'}]),
+            ('port', _testport.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+        attrs = {
+            'fixed_ips': [
+                {'ip_address': '0.0.0.1'},
+                {'ip_address': '10.0.0.12'},
+            ],
+        }
+        self.network.update_port.assert_called_once_with(_testport, **attrs)
+        self.assertIsNone(result)
+
+    def test_set_port_fixed_ip_clear(self):
+        _testport = network_fakes.FakePort.create_one_port(
+            {'fixed_ips': [{'ip_address': '0.0.0.1'}]})
+        self.network.find_port = mock.Mock(return_value=_testport)
+        arglist = [
+            '--fixed-ip', 'ip-address=10.0.0.12',
+            '--no-fixed-ip',
+            _testport.name,
+        ]
+        verifylist = [
+            ('fixed_ip', [{'ip-address': '10.0.0.12'}]),
+            ('no_fixed_ip', True)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+        attrs = {
+            'fixed_ips': [
+                {'ip_address': '10.0.0.12'},
+            ],
+        }
+        self.network.update_port.assert_called_once_with(_testport, **attrs)
+        self.assertIsNone(result)
+
+    def test_set_port_dns_name(self):
         arglist = [
             '--dns-name', '8.8.8.8',
             self._port.name,
@@ -835,28 +995,7 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_append_fixed_ip(self):
-        _testport = network_fakes.FakePort.create_one_port(
-            {'fixed_ips': [{'ip_address': '0.0.0.1'}]})
-        self.network.find_port = mock.Mock(return_value=_testport)
-        arglist = [
-            '--fixed-ip', 'ip-address=10.0.0.12',
-            _testport.name,
-        ]
-        verifylist = [
-            ('fixed_ip', [{'ip-address': '10.0.0.12'}]),
-            ('port', _testport.name),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        result = self.cmd.take_action(parsed_args)
-        attrs = {
-            'fixed_ips': [
-                {'ip_address': '10.0.0.12'}, {'ip_address': '0.0.0.1'}],
-        }
-        self.network.update_port.assert_called_once_with(_testport, **attrs)
-        self.assertIsNone(result)
-
-    def test_overwrite_binding_profile(self):
+    def test_set_port_overwrite_binding_profile(self):
         _testport = network_fakes.FakePort.create_one_port(
             {'binding_profile': {'lok_i': 'visi_on'}})
         self.network.find_port = mock.Mock(return_value=_testport)
@@ -878,29 +1017,26 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(_testport, **attrs)
         self.assertIsNone(result)
 
-    def test_overwrite_fixed_ip(self):
+    def test_overwrite_mac_address(self):
         _testport = network_fakes.FakePort.create_one_port(
-            {'fixed_ips': [{'ip_address': '0.0.0.1'}]})
+            {'mac_address': '11:22:33:44:55:66'})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
-            '--fixed-ip', 'ip-address=10.0.0.12',
-            '--no-fixed-ip',
+            '--mac-address', '66:55:44:33:22:11',
             _testport.name,
         ]
         verifylist = [
-            ('fixed_ip', [{'ip-address': '10.0.0.12'}]),
-            ('no_fixed_ip', True)
+            ('mac_address', '66:55:44:33:22:11'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
         attrs = {
-            'fixed_ips': [
-                {'ip_address': '10.0.0.12'}],
+            'mac_address': '66:55:44:33:22:11',
         }
         self.network.update_port.assert_called_once_with(_testport, **attrs)
         self.assertIsNone(result)
 
-    def test_set_this(self):
+    def test_set_port_this(self):
         arglist = [
             '--disable',
             '--no-fixed-ip',
@@ -925,7 +1061,7 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_set_that(self):
+    def test_set_port_that(self):
         arglist = [
             '--description', 'newDescription',
             '--enable',
@@ -959,22 +1095,7 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_set_nothing(self):
-        arglist = [
-            self._port.name,
-        ]
-        verifylist = [
-            ('port', self._port.name),
-        ]
-
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        result = self.cmd.take_action(parsed_args)
-
-        attrs = {}
-        self.network.update_port.assert_called_once_with(self._port, **attrs)
-        self.assertIsNone(result)
-
-    def test_set_invalid_json_binding_profile(self):
+    def test_set_port_invalid_json_binding_profile(self):
         arglist = [
             '--binding-profile', '{"parent_name"}',
             'test-port',
@@ -985,7 +1106,7 @@ class TestSetPort(TestPort):
                           arglist,
                           None)
 
-    def test_set_invalid_key_value_binding_profile(self):
+    def test_set_port_invalid_key_value_binding_profile(self):
         arglist = [
             '--binding-profile', 'key',
             'test-port',
@@ -996,7 +1117,7 @@ class TestSetPort(TestPort):
                           arglist,
                           None)
 
-    def test_set_mixed_binding_profile(self):
+    def test_set_port_mixed_binding_profile(self):
         arglist = [
             '--binding-profile', 'foo=bar',
             '--binding-profile', '{"foo2": "bar2"}',
@@ -1016,7 +1137,7 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_set_security_group(self):
+    def test_set_port_security_group(self):
         sg = network_fakes.FakeSecurityGroup.create_one_security_group()
         self.network.find_security_group = mock.Mock(return_value=sg)
         arglist = [
@@ -1024,26 +1145,25 @@ class TestSetPort(TestPort):
             self._port.name,
         ]
         verifylist = [
-            ('security_groups', [sg.id]),
+            ('security_group', [sg.id]),
             ('port', self._port.name),
         ]
-
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        result = self.cmd.take_action(parsed_args)
 
+        result = self.cmd.take_action(parsed_args)
         attrs = {
-            'security_groups': [sg.id],
+            'security_group_ids': [sg.id],
         }
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_append_security_group(self):
+    def test_set_port_security_group_append(self):
         sg_1 = network_fakes.FakeSecurityGroup.create_one_security_group()
         sg_2 = network_fakes.FakeSecurityGroup.create_one_security_group()
         sg_3 = network_fakes.FakeSecurityGroup.create_one_security_group()
         self.network.find_security_group = mock.Mock(side_effect=[sg_2, sg_3])
         _testport = network_fakes.FakePort.create_one_port(
-            {'security_groups': [sg_1.id]})
+            {'security_group_ids': [sg_1.id]})
         self.network.find_port = mock.Mock(return_value=_testport)
         arglist = [
             '--security-group', sg_2.id,
@@ -1051,18 +1171,19 @@ class TestSetPort(TestPort):
             _testport.name,
         ]
         verifylist = [
-            ('security_groups', [sg_2.id, sg_3.id]),
+            ('security_group', [sg_2.id, sg_3.id]),
             ('port', _testport.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
         result = self.cmd.take_action(parsed_args)
         attrs = {
-            'security_groups': [sg_1.id, sg_2.id, sg_3.id],
+            'security_group_ids': [sg_1.id, sg_2.id, sg_3.id],
         }
         self.network.update_port.assert_called_once_with(_testport, **attrs)
         self.assertIsNone(result)
 
-    def test_set_no_security_groups(self):
+    def test_set_port_security_group_clear(self):
         arglist = [
             '--no-security-group',
             self._port.name,
@@ -1071,21 +1192,20 @@ class TestSetPort(TestPort):
             ('no_security_group', True),
             ('port', self._port.name),
         ]
-
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-        result = self.cmd.take_action(parsed_args)
 
+        result = self.cmd.take_action(parsed_args)
         attrs = {
-            'security_groups': [],
+            'security_group_ids': [],
         }
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_overwrite_security_group(self):
+    def test_set_port_security_group_replace(self):
         sg1 = network_fakes.FakeSecurityGroup.create_one_security_group()
         sg2 = network_fakes.FakeSecurityGroup.create_one_security_group()
         _testport = network_fakes.FakePort.create_one_port(
-            {'security_groups': [sg1.id]})
+            {'security_group_ids': [sg1.id]})
         self.network.find_port = mock.Mock(return_value=_testport)
         self.network.find_security_group = mock.Mock(return_value=sg2)
         arglist = [
@@ -1094,18 +1214,19 @@ class TestSetPort(TestPort):
             _testport.name,
         ]
         verifylist = [
-            ('security_groups', [sg2.id]),
+            ('security_group', [sg2.id]),
             ('no_security_group', True)
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
         result = self.cmd.take_action(parsed_args)
         attrs = {
-            'security_groups': [sg2.id],
+            'security_group_ids': [sg2.id],
         }
         self.network.update_port.assert_called_once_with(_testport, **attrs)
         self.assertIsNone(result)
 
-    def test_set_allowed_address_pair(self):
+    def test_set_port_allowed_address_pair(self):
         arglist = [
             '--allowed-address', 'ip-address=192.168.1.123',
             self._port.name,
@@ -1124,7 +1245,7 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_append_allowed_address_pair(self):
+    def test_set_port_append_allowed_address_pair(self):
         _testport = network_fakes.FakePort.create_one_port(
             {'allowed_address_pairs': [{'ip_address': '192.168.1.123'}]})
         self.network.find_port = mock.Mock(return_value=_testport)
@@ -1147,7 +1268,7 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(_testport, **attrs)
         self.assertIsNone(result)
 
-    def test_overwrite_allowed_address_pair(self):
+    def test_set_port_overwrite_allowed_address_pair(self):
         _testport = network_fakes.FakePort.create_one_port(
             {'allowed_address_pairs': [{'ip_address': '192.168.1.123'}]})
         self.network.find_port = mock.Mock(return_value=_testport)
@@ -1171,7 +1292,7 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(_testport, **attrs)
         self.assertIsNone(result)
 
-    def test_set_no_allowed_address_pairs(self):
+    def test_set_port_no_allowed_address_pairs(self):
         arglist = [
             '--no-allowed-address',
             self._port.name,
@@ -1190,7 +1311,7 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
-    def test_port_security_enabled(self):
+    def test_set_port_security_enabled(self):
         arglist = [
             '--enable-port-security',
             self._port.id,
@@ -1208,7 +1329,7 @@ class TestSetPort(TestPort):
             'port_security_enabled': True,
         })
 
-    def test_port_security_disabled(self):
+    def test_set_port_security_disabled(self):
         arglist = [
             '--disable-port-security',
             self._port.id,
@@ -1226,6 +1347,30 @@ class TestSetPort(TestPort):
             'port_security_enabled': False,
         })
 
+    def test_set_port_with_qos(self):
+        qos_policy = network_fakes.FakeNetworkQosPolicy.create_one_qos_policy()
+        self.network.find_qos_policy = mock.Mock(return_value=qos_policy)
+        _testport = network_fakes.FakePort.create_one_port(
+            {'qos_policy_id': None})
+        self.network.find_port = mock.Mock(return_value=_testport)
+        arglist = [
+            '--qos-policy', qos_policy.id,
+            _testport.name,
+        ]
+        verifylist = [
+            ('qos_policy', qos_policy.id),
+            ('port', _testport.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        result = self.cmd.take_action(parsed_args)
+
+        attrs = {
+            'qos_policy_id': qos_policy.id,
+        }
+        self.network.update_port.assert_called_once_with(_testport, **attrs)
+        self.assertIsNone(result)
+
 
 class TestShowPort(TestPort):
 
@@ -1289,6 +1434,7 @@ class TestUnsetPort(TestPort):
             '--fixed-ip',
             'subnet=042eb10a-3a18-4658-ab-cf47c8d03152,ip-address=1.0.0.0',
             '--binding-profile', 'Superman',
+            '--qos-policy',
             self._testport.name,
         ]
         verifylist = [
@@ -1296,6 +1442,7 @@ class TestUnsetPort(TestPort):
                 'subnet': '042eb10a-3a18-4658-ab-cf47c8d03152',
                 'ip-address': '1.0.0.0'}]),
             ('binding_profile', ['Superman']),
+            ('qos_policy', True),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1305,7 +1452,8 @@ class TestUnsetPort(TestPort):
             'fixed_ips': [{
                 'subnet_id': '042eb10a-3a18-4658-ab-cf47c8d03152',
                 'ip_address': '0.0.0.1'}],
-            'binding:profile': {'batman': 'Joker'}
+            'binding:profile': {'batman': 'Joker'},
+            'qos_policy_id': None
         }
         self.network.update_port.assert_called_once_with(
             self._testport, **attrs)
@@ -1347,7 +1495,7 @@ class TestUnsetPort(TestPort):
         _fake_sg1 = network_fakes.FakeSecurityGroup.create_one_security_group()
         _fake_sg2 = network_fakes.FakeSecurityGroup.create_one_security_group()
         _fake_port = network_fakes.FakePort.create_one_port(
-            {'security_groups': [_fake_sg1.id, _fake_sg2.id]})
+            {'security_group_ids': [_fake_sg1.id, _fake_sg2.id]})
         self.network.find_port = mock.Mock(return_value=_fake_port)
         self.network.find_security_group = mock.Mock(return_value=_fake_sg2)
         arglist = [
@@ -1355,14 +1503,14 @@ class TestUnsetPort(TestPort):
             _fake_port.name,
         ]
         verifylist = [
-            ('security_groups', [_fake_sg2.id]),
+            ('security_group_ids', [_fake_sg2.id]),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         result = self.cmd.take_action(parsed_args)
 
         attrs = {
-            'security_groups': [_fake_sg1.id]
+            'security_group_ids': [_fake_sg1.id]
         }
         self.network.update_port.assert_called_once_with(
             _fake_port, **attrs)
@@ -1372,14 +1520,14 @@ class TestUnsetPort(TestPort):
         _fake_sg1 = network_fakes.FakeSecurityGroup.create_one_security_group()
         _fake_sg2 = network_fakes.FakeSecurityGroup.create_one_security_group()
         _fake_port = network_fakes.FakePort.create_one_port(
-            {'security_groups': [_fake_sg1.id]})
+            {'security_group_ids': [_fake_sg1.id]})
         self.network.find_security_group = mock.Mock(return_value=_fake_sg2)
         arglist = [
             '--security-group', _fake_sg2.id,
             _fake_port.name,
         ]
         verifylist = [
-            ('security_groups', [_fake_sg2.id]),
+            ('security_group_ids', [_fake_sg2.id]),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
