@@ -823,6 +823,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': False,
+            'project_id': None,
+            'user_id': None,
+            'display_name': None,
+            'status': None,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         self.assertEqual(self.columns, columns)
 
         server = self.mock_volume.attachments[0]['server_id']
@@ -853,6 +866,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': True,
+            'project_id': self.project.id,
+            'user_id': None,
+            'display_name': None,
+            'status': None,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         self.assertEqual(self.columns, columns)
 
         server = self.mock_volume.attachments[0]['server_id']
@@ -885,6 +911,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': True,
+            'project_id': self.project.id,
+            'user_id': None,
+            'display_name': None,
+            'status': None,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         self.assertEqual(self.columns, columns)
 
         server = self.mock_volume.attachments[0]['server_id']
@@ -915,6 +954,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': False,
+            'project_id': None,
+            'user_id': self.user.id,
+            'display_name': None,
+            'status': None,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         self.assertEqual(self.columns, columns)
         server = self.mock_volume.attachments[0]['server_id']
         device = self.mock_volume.attachments[0]['device']
@@ -946,6 +998,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': False,
+            'project_id': None,
+            'user_id': self.user.id,
+            'display_name': None,
+            'status': None,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         self.assertEqual(self.columns, columns)
 
         server = self.mock_volume.attachments[0]['server_id']
@@ -976,6 +1041,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': False,
+            'project_id': None,
+            'user_id': None,
+            'display_name': self.mock_volume.name,
+            'status': None,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         self.assertEqual(self.columns, columns)
 
         server = self.mock_volume.attachments[0]['server_id']
@@ -1006,6 +1084,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': False,
+            'project_id': None,
+            'user_id': None,
+            'display_name': None,
+            'status': self.mock_volume.status,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         self.assertEqual(self.columns, columns)
 
         server = self.mock_volume.attachments[0]['server_id']
@@ -1036,6 +1127,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': True,
+            'project_id': None,
+            'user_id': None,
+            'display_name': None,
+            'status': None,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         self.assertEqual(self.columns, columns)
 
         server = self.mock_volume.attachments[0]['server_id']
@@ -1067,6 +1171,19 @@ class TestVolumeList(TestVolume):
 
         columns, data = self.cmd.take_action(parsed_args)
 
+        search_opts = {
+            'all_tenants': False,
+            'project_id': None,
+            'user_id': None,
+            'display_name': None,
+            'status': None,
+        }
+        self.volumes_mock.list.assert_called_once_with(
+            search_opts=search_opts,
+            marker=None,
+            limit=None,
+        )
+
         collist = [
             'ID',
             'Display Name',
@@ -1251,6 +1368,24 @@ class TestVolumeSet(TestVolume):
         # Get the command object to test
         self.cmd = volume.SetVolume(self.app, None)
 
+    def test_volume_set_property(self):
+        arglist = [
+            '--property', 'a=b',
+            '--property', 'c=d',
+            self.new_volume.id,
+        ]
+        verifylist = [
+            ('property', {'a': 'b', 'c': 'd'}),
+            ('volume', self.new_volume.id),
+            ('bootable', False),
+            ('non_bootable', False)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+        self.volumes_mock.set_metadata.assert_called_with(
+            self.new_volume.id, parsed_args.property)
+
     def test_volume_set_image_property(self):
         arglist = [
             '--image-property', 'Alpha=a',
