@@ -291,7 +291,7 @@ class ListVolume(command.Lister):
             '--limit',
             type=int,
             action=parseractions.NonNegativeAction,
-            metavar='<limit>',
+            metavar='<num-volumes>',
             help=_('Maximum number of volumes to display'),
         )
         return parser
@@ -439,6 +439,15 @@ class SetVolume(command.Command):
             type=int,
             help=_('Extend volume size in GB'),
         )
+        parser.add_argument(
+            "--no-property",
+            dest="no_property",
+            action="store_true",
+            help=_("Remove all properties from <volume> "
+                   "(specify both --no-property and --property to "
+                   "remove the current properties before setting "
+                   "new properties.)"),
+        )
         parser.add_argument(
             '--property',
             metavar='<key=value>',
@@ -489,6 +498,15 @@ class SetVolume(command.Command):
             except Exception as e:
                 LOG.error(_("Failed to set volume size: %s"), e)
                 result += 1
+
+        if parsed_args.no_property:
+            try:
+                volume_client.volumes.delete_metadata(
+                    volume.id, volume.metadata.keys())
+            except Exception as e:
+                LOG.error(_("Failed to clean volume properties: %s"), e)
+                result += 1
+
         if parsed_args.property:
             try:
                 volume_client.volumes.set_metadata(
