@@ -341,14 +341,14 @@ class ListVolume(command.Lister):
         )
         parser.add_argument(
             '--marker',
-            metavar='<marker>',
+            metavar='<volume>',
             help=_('The last volume ID of the previous page'),
         )
         parser.add_argument(
             '--limit',
             type=int,
             action=parseractions.NonNegativeAction,
-            metavar='<limit>',
+            metavar='<num-volumes>',
             help=_('Maximum number of volumes to display'),
         )
         return parser
@@ -417,16 +417,19 @@ class ListVolume(command.Lister):
             project_id = identity_common.find_project(
                 identity_client,
                 parsed_args.project,
-                parsed_args.project_domain)
+                parsed_args.project_domain).id
 
         user_id = None
         if parsed_args.user:
             user_id = identity_common.find_user(identity_client,
                                                 parsed_args.user,
-                                                parsed_args.user_domain)
+                                                parsed_args.user_domain).id
+
+        # set value of 'all_tenants' when using project option
+        all_projects = bool(parsed_args.project) or parsed_args.all_projects
 
         search_opts = {
-            'all_tenants': parsed_args.all_projects,
+            'all_tenants': all_projects,
             'project_id': project_id,
             'user_id': user_id,
             'display_name': parsed_args.name,
@@ -520,6 +523,15 @@ class SetVolume(command.Command):
             metavar='<description>',
             help=_('New volume description'),
         )
+        parser.add_argument(
+            "--no-property",
+            dest="no_property",
+            action="store_true",
+            help=_("Remove all properties from <volume> "
+                   "(specify both --no-property and --property to "
+                   "remove the current properties before setting "
+                   "new properties.)"),
+        )
         parser.add_argument(
             '--property',
             metavar='<key=value>',
@@ -558,7 +570,7 @@ class SetVolume(command.Command):
             choices=['never', 'on-demand'],
             help=_('Migration policy while re-typing volume '
                    '("never" or "on-demand", default is "never" ) '
-                   '(available only when "--type" option is specified)'),
+                   '(available only when --type option is specified)'),
         )
         bootable_group = parser.add_mutually_exclusive_group()
         bootable_group.add_argument(
@@ -604,6 +616,14 @@ class SetVolume(command.Command):
                 LOG.error(_("Failed to set volume size: %s"), e)
                 result += 1
 
+        if parsed_args.no_property:
+            try:
+                volume_client.volumes.delete_metadata(
+                    volume.id, volume.metadata.keys())
+            except Exception as e:
+                LOG.error(_("Failed to clean volume properties: %s"), e)
+                result += 1
+
         if parsed_args.property:
             try:
                 volume_client.volumes.set_metadata(
